{
 	File:		FileManagerTypes.p
 
 	Contains:	FileManager Fundamental Declarations & Definitions
 
 	Version:	Technology:	System 8
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
}
{$IFC UNDEFINED UsingIncludes}
{$SETC UsingIncludes := 0}
{$ENDC}

{$IFC NOT UsingIncludes}
 UNIT FileManagerTypes;
 INTERFACE
{$ENDC}

{$IFC UNDEFINED __FILEMANAGERTYPES__}
{$SETC __FILEMANAGERTYPES__ := 1}

{$I+}
{$SETC FileManagerTypesIncludes := UsingIncludes}
{$SETC UsingIncludes := 1}

{$IFC UNDEFINED __TYPES__}
{$I Types.p}
{$ENDC}
{$IFC UNDEFINED __ERRORS__}
{$I Errors.p}
{$ENDC}
{$IFC UNDEFINED __KERNEL__}
{$I Kernel.p}
{$ENDC}
{$IFC UNDEFINED __TEXTOBJECTS__}
{$I TextObjects.p}
{$ENDC}
{$IFC UNDEFINED __MATH64__}
{$I Math64.p}
{$ENDC}

{$PUSH}
{$ALIGN POWER}
{$LibExport+}

{$IFC FOR_SYSTEM8_PREEMPTIVE }
{ >>>>>>>>>>>>>>>>>>>>>>>>>>>>> F o u n d a t i o n  D e f i n i t i o n s <<<<<<<<<<<<<<<<<<<<<<<<<<<<< }
{
****************************************************************************
	CONSTANTS & TYPES
****************************************************************************
}
{
	FSAgentObjID is used to indicate a specific registered FS Agent.
	This value is not persistent across rebooting the machine or
	re-registering the given agent. It is in fact an object ID to
	which requests for the given agent should be sent.
}

TYPE
	FSAgentObjID						= ObjectID;
{
	FSBufferDescriptor
		Tells the File Manager about the location and size of a buffer.
		Buffers are nominally arrays of structures, so FSBufferDescriptor
		lets you indicate the size of an array element, and the number of
		elements.
	
	bufferAddress
		Starting address of the buffer.
	itemSize
		The size (in bytes) of one array element.  This would typically be
		the size of an FSPropertyStatusElement, or the size of the caller's
		property structure (i.e., for all properties of a single object).
	itemCount
		The number of array elements.  When the buffer is for properties,
		this is usually equal to the number of objects.  When the buffer
		is for status, this is usually the number of objects times the
		number of properties per object (i.e., the total number of properties).

		If itemCount is not 1, then the array elements are at addresses:
		bufferAddress, bufferAddress+itemSize, bufferAddress+2*itemSize, etc.
	
	Note: the actual length of the buffer is itemSize * itemCount bytes.
	
	Note: Some calls that take a (pointer to a) buffer descriptor allow you
		to pass NULL for that parameter.  In that case, the API will create
		a buffer descriptor for you.  It will set the itemCount to 1, and the
		bufferAddress and itemSize based on the FSBufferElementDescriptor's
		associated with the buffer.  The bufferAddress will be the least offset
		and the itemSize will be the maximum (length + offset).  The actual
		FSBufferElementDescriptors used by the File Manager will have their
		offset fields decremented by bufferAddress.  This provides scatter-
		gather capability.
}
	FSBufferDescriptorPtr = ^FSBufferDescriptor;
	FSBufferDescriptor = RECORD
		bufferAddress:			LogicalAddress;
		itemSize:				ByteCount;
		itemCount:				ItemCount;
	END;

{
	FSBufferElementDescriptor
		Used to describe a field within a buffer described by an FSBufferDescriptor.
		(Actually, it describes a field within one of the array elements.)
	
	length
		Size (in bytes) of the field.
	offset
		Offset (in bytes) from the start of an array element to the start of the
		field.  If the supplied pointer to the FSBufferDescriptor was NULL, then
		this is the actual (logical) address of the data.  See FSBufferDescriptor.
}
	FSBufferElementDescriptorPtr = ^FSBufferElementDescriptor;
	FSBufferElementDescriptor = RECORD
		length:					ByteCount;
		offset:					ByteOffset;
	END;

{
	// it's been suggested that this should be wide...
	// This type isn't used in any of the interface files; maybe
	// it should be removed?
}
	FSCount								= UInt32;
{
	FSDate
		The standard type used to represent a date/time value.  For example, the
		modification and creation date properties of an object would be formatted
		as FSDates.
		
	Note: an FSDate is really just a TimeObject, so you can use all the normal
		TimeObject facilities with them.
}
	FSDate								= TimeObject;
	FSDatePtr 							= ^FSDate;
{
	FSName
		The standard type used for the name property of an object.
	ConstFSName
		An FSName that will not be changed by a called routine.  Used in
		function declarations only.
		
	NOTE: Only persistent text objects are supported.
}
	FSName								= TextObject;
	ConstFSName							= ConstTextObject;
{
	FSObjectPrivileges
		A set of flags that describe what operations can be performed
		on an open stream or mapped file.
	
	kFSCanReadForkProperty
		For streams, allow read operations (FSStreamSimpleRead and FSStreamRead).
		For mapped files, allow the file to be mapped such that the memory can be
		read (this is required).
	kFSCanWriteForkProperty
		For streams, allow write operations (FSStreamSimpleWrite and FSStreamWrite).
		For mapped files, allow the file to be mapped such that the memory can be
		written.  If not set, then the memory can be mapped read-only.
	kFSCanExtendForkProperty
		For streams, allow the fork to grow (calls to FSStreamSetAbsoluteEOF,
		FSStreamSetEOF, or FSStreamAllocate that would cause the EOF to become
		larger).  For mapped files, allow the memory area to grow, and allow
		changes to addresses beyond the EOF to actually be written to the fork;
		also allows FSMappedFileSetEOF to set the EOF to a larger value.
	kFSCanTruncateForkProperty
		For streams, allow the fork to shrink (calls to FSStreamSetAbsoluteEOF,
		FSStreamSetEOF, or FSStreamReleaseAllocation that would cause the EOF
		to become smaller).  For mapped files, allow FSMappedFileSetEOF to change
		the EOF to a smaller value.
	
	Note: some volume formats may not be able to control each of these operations
		individually.  You would usually set or clear the kFSCanWriteForkProperty,
		kFSCanExtendForkProperty and kFSCanTruncateForkProperty bits together.
}

CONST
	kFSInvalidPrivileges		= $00000000;
	kFSCanReadForkProperty		= $00000200;
	kFSCanWriteForkProperty		= $00000400;
	kFSCanExtendForkProperty	= $00000800;
	kFSCanTruncateForkProperty	= $00001000;


TYPE
	FSObjectPrivileges					= OptionBits;
{
	FSObjectPrivilegesDenied
		A set of flags that describes which operations CANNOT be performed on
		an open stream or mapped file.  These are the same flags as FSObjectPrivileges,
		but the name of the data type is changed as a reminder that the operations
		should NOT be allowed for the indicated entity.
}
	FSObjectPrivilegesDenied			= FSObjectPrivileges;
{
	FSOffset
		A signed 64-bit integer used to describe an offset into a property, or the
		difference between two positions.  It is signed because it is a relative
		value (such as a negative offset from EOF).
}
	FSOffset							= SInt64;
	FSOffsetPtr 						= ^FSOffset;
{
	FSPropertyStatusElement
		Used for returning status for a single property of an object, when a call
		can manipulate more than one property.  Also used to return the actual
		length of a returned property (since buffer underflow is not an error).
		
		If a call returns the error E_PropertyException, then one or more properties
		had an error, and you should check the property status array.  For example,
		this would be used when getting multiple properties; since some might not
		exist, you'd want an error for just those properties, but still allow the
		call to complete for the other properties.
	
	propertyStatus
		The status of the operation on the associated property.
	propertyValueActualSize
		The actual size (in bytes) of the returned property.  If propertyStatus
		was E_PropertyBufferFieldTooSmall, then this field contains the actual
		size of the property so you can allocate enough space and try again (note:
		no valid data will be returned for the property in this case -- you get
		all or nothing).
}
	FSPropertyStatusElementPtr = ^FSPropertyStatusElement;
	FSPropertyStatusElement = RECORD
		propertyStatus:			OSStatus;
		propertyValueActualSize: ByteCount;
	END;

{
	kFSSingleInstanceProperty
		A constant used for constructing the tag for a property, when the
		property can only have one instance.
}

CONST
	kFSSingleInstanceProperty	= 0;

{
	FSFileManagerPropertyTagVersion
		A subfield of some property tags, that indicates which version of
		the property should be used.  This is typically used when the format
		of a property changes over time, to allow the older formats to be supported
		in newer versions of the File Manager or volume formats.  For now, you
		should always use kFSCurrentReleasedVersion.
}
	kFSInvalidPropertyTagVersion = 0;
	kFSD10Version				= 1;
	kFSD11NewAttributesVersion	= 2;
	kFSCurrentReleasedVersion	= 2;


TYPE
	FSFileManagerPropertyTagVersion		= UInt16;
{
	FSSize
		The size of a property (or part of a property).
	
	Note: this is a signed 64-bit value.  Since positions within a property
		(eg., in stream access) are specified by an FSOffset, which is also
		a signed 64-bit quantity, the maximum size of a property is restricted
		to 2^63 bytes.  Having FSSize be a signed quantity makes it easier to
		mix with FSOffset.
}
	FSSize								= SInt64;
	FSSizePtr 							= ^FSSize;
{
	FSVolumeObjID
		A run-time value that identifies a particular volume.  It may be used
		from any process (and passed between processes).  It becomes invalid
		when the volume is unmounted.  Note: FSVolumeObjID's are not reused
		immediately, so you can use notifications to invalidate any
		FSVolumeObjID's you may have in your own structures.
		
		For most File Manager operations, you will want to use the
		FSVolumeObjIDResolve call to obtain an FSObjectRef for the volume.
}
	FSVolumeObjID						= ObjectID;
{
	FSVolumeSetObjID
		A run-time value that identifies a particular set of volumes.  It may
		be used from any process (and passed between processes).  It becomes
		invalid when the volume set is deleted.  Note: FSVolumeSetObjID's are
		not reused immediately, so you can use notifications to invalidate any
		FSVolumeSetObjID's you may have in your own structures.
		
		Note: At this time, there is only one FSVolumeSetObjID:
			kFStheBootVolumeSetObject.  This corresponds to the set of volumes
			you would see on the Finder's desktop.  In the future, there may
			be other volume sets.  The value kFStheBootVolumeSetObject will
			always be valid.

		For most File Manager operations, you will want to use the
		FSVolumeSetGetInformation call to obtain an FSObjectRef for the volume
		set.
}
	FSVolumeSetObjID					= ObjectID;
{ >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> C o n t a i n e r s <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< }
{
****************************************************************************
	OBJECTS
****************************************************************************
}
{
	FSObjectPersistentReference
		A structure used to persistently identify an object on a given volume.
		It is the caller's responsibility to keep track of the volume associated
		with the object.
		
		A persistent reference is a best-effort attempt to identify an object
		over time.  For volume formats that have unique identifiers for all
		objects on a volume, those identifiers would usually be part of the
		persistent reference.  It may also contain other information to help
		locate or verify the object (especially if there are no unique identifiers,
		or they are reused quickly).
		
		It is up to the volume format to determine what to store in a persistent
		reference.  For some volume formats, changes to the object may cause the
		persistent reference to no longer find the object.  It is even possible
		that a change to one or more objects may cause the persistent reference
		to resolve to a different object (which appears to be the original object).
}
	FSObjectPersistentReferencePtr = ^FSObjectPersistentReference;
	FSObjectPersistentReference = RECORD
		count:					ByteCount;
		reference:				ARRAY [0..0] OF UInt32;
	END;

{
	FSObjectRef
		A run-time identifier for an object controlled by the File Manager.
		FSObjectRef's are used by almost every call that indicates an object.
		FSObjectRef's are allocated and disposed on a per-process basis.  If
		multiple processes have an FSObjectRef for the same object, then the
		FSObjectRef's will have the same value.  If an FSObjectRef is disposed
		and later allocated for the same object, a different value for the
		FSObjectRef may be returned.
		
		Allocated FSObjectRef's consume memory and other resources inside the
		File Manager.  You should dispose of them when you no longer need to
		identify the object.  When a process terminates, all of its object
		ref's are disposed.
		
		When an FSObjectRef is returned by a File Manager call, it is auto-
		matically allocated for the caller's process.  This is true even when
		the FSObjectRef is returned as a property of an object (as well as
		an explicit output parameter of type FSObjectRef).
		
		There are calls to obtain an FSObjectRef for an object specified by
		FSVolumeObjID, FSVolumeSetObjID, and persistent reference.  There
		are calls to allocate an FSObjectRef for another process, or allocate
		another copy for your own process.  There are calls to dispose an
		FSObjectRef, or dispose many of them at once (typically for cleaning
		up after having FSObjectRef's returned as properties by some other
		call).
}
	FSObjectRef = ^LONGINT;
{  }
{
============================================================================
	theBootVolumeSet
============================================================================
}
{
	kFStheBootVolumeObject
		An FSVolumeObjID for the volume that the system was booted from.
	kFStheBootVolumeSetObject
		An FSVolumeSetObjID for the volume set containing the boot volume.
}
{
============================================================================
	Volumes
============================================================================
}
{
	FSMountAccessConstraints
		Specifies which operations can be performed on a volume by the indicated
		tasks.  These constraints are given when the volume is mounted.  They
		would typically be used by utility programs that need exclusive access
		to a volume.
	
	allowThisTask
		Operations allowed on the volume, for the task that mounted the volume.
	denyThisKernelProcess
		Operations forbidden on the volume, for any task in the process that
		mounted the volume (other than the task that actually mounted the volume).
		// This seems non-sensical, given the transitory nature of some tasks.
	denyOtherKernelProcesses
		Operations forbidden on the volume, for all processes other than the
		one that mounted the volume.
		
	// These clearly shouldn't be FSObjectPrivileges.  There should be some
	// other type for privileges or contstraints on mounting (since object
	// privileges explicitly refer to forks).
}
	FSMountAccessConstraintsPtr = ^FSMountAccessConstraints;
	FSMountAccessConstraints = RECORD
		allowThisTask:			FSObjectPrivileges;
		denyThisKernelProcess:	FSObjectPrivilegesDenied;
		denyOtherKernelProcesses: FSObjectPrivilegesDenied;
	END;

{
****************************************************************************
	PROPERTIES
****************************************************************************
}
{
	FSPropertyCreator
		Analogous to a file's creator, this is the creator for a property or
		set of properties.  This can also be thought of as a class of properties.
		A property's creator defines which selectors are allowed.
		
		For example, the creator kFSFileManagerCreator is used for all properties
		defined by the File Manager (such as an object's name, creation date,
		object ref, etc.).  The creator kFSUserExperienceCreator is used for
		properties used by the user experience (such as the Finder); it includes
		properties such as icons and comments.
		
		When application-defined properties are supported, an application could
		define and create new properties whose creator is the same as the creator
		for their application.
}
	FSPropertyCreator					= OSType;
{
	FSPropertySelector
		Analogous to a file's type, this identifies a specific property within a given
		creator (or class of properties). The set of allowable selectors and their
		meanings are defined based on the property's creator.
		
		The same selector may be used with different creators for completely different
		properties.
		
		There is one selector that is reserved regardless of creator:
		kFSForkPropertySelector.
		
		// Should Apple reserve values consisting of no upper-case letters, much like
		// we reserve creators?
}
	FSPropertySelector					= OSType;
{
	FSPropertyAttribute
		Identifies a particular attribute of a given property (as specified by
		creator and selector).  You are most likely to use the value and size
		attributes of a property.
		
		Apple Computer reserves the right to define the set of valid attributes.
}
	FSPropertyAttribute					= OSType;
{
	FSPropertyTag
		Allows you to identify a particular instance, version, or format of
		a property.  A FSPropertyTag is an opaque structure of 8 bytes.  The
		actual format is defined by the property's creator (and possibly selector).
		
		An object may have multiple instances of a given property.  For example, a
		word processor document might have an author property; if there is more
		than one author, there could be multiple instances of the property.  You
		would use the tag to indicate which instance you want.  A property's
		creator would typically define a data type for their tag(s), and possibly
		a function or macro to help in assigning them.
		
		Likewise, an object may have multiple formats.  For example, an object's
		name can bet set or retrieved as: a text object, a Pascal string (ASCII
		text with leading length byte), a C string (ASCII text with trailing 0
		byte), or as pure ASCII text (whose length is denoted by the size attribute).
		
		Many property tags contain a version subfield.  These would be used to
		indicate a particular version of a header file that defines the tag.  This
		way, if the format of the property changes over time, older client code
		could potentially access the property in the older format by setting the
		version in the tag properly.
}
{  this is needed to force our distinguished constants out of the code section }
	FSPropertyTag						= ARRAY [0..1] OF Ptr;
{
	FSProperty
		Compeletely specifies a given instance (or version or format) of a
		given attribute of a given property (i.e. creator and selector).
}
	FSPropertyPtr = ^FSProperty;
	FSProperty = RECORD
		creator:				FSPropertyCreator;
		selector:				FSPropertySelector;
		attribute:				FSPropertyAttribute;
		tag:					FSPropertyTag;
	END;

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished FSProperty Creators
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
	FSPropertyDistinguishedCreators
		These are the well-known creators used in properties.
	kFSFileManagerCreator
		Properties defined by the File Manager itself (such as an object's
		name, creation date, etc.).
	kFSUserExperienceCreator
		Properties defined by Apple's user experience (such as the Finder);
		includes such properties as an object's icon or comment.
	kFSUniverseCreator
		Properties unique to the Universe object, that would not be applicable
		to other objects.
	kFSBootVolumeSetCreator
		Properties unique to the boot volume set, that would not be applicable
		to other objects.
		// shouldn't this be just a volume set creator?  Presumably, it would
		// be used for properties that might be supported by other volume sets.
}

CONST
	kFSFileManagerCreator		= 'fmgr';
	kFSUniverseCreator			= 'fmun';
	kFSBootVolumeSetCreator		= 'fmbv';
	kFSUserExperienceCreator	= 'uexp';

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Fork Property Distinguished Selector
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
	FSForkPropertyDistinguishedSelector
		These are the set of selectors that are reserved across all creators.
	kFSForkPropertySelector
		This selector indicates a fork property: a property whose value attribute
		is a fork value attribute.  The value can be accessed as an FSStream
		or as a mapped file.  All other properties, or other attributes of a
		fork property may not be accessed this way.
}
	kFSForkPropertySelector		= 'fork';						{  }

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished FSProperty Attributes
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
	FSPropertyDistinguishedAttributes
		These are the defined attributes for all properties.
	
	kFSValueAttribute
		The value of a property.  It consists of 0 to 2^63 bytes for fork
		properties, or 0 to (2^32)-1 bytes for non-fork properties.  For
		non-fork properties, the value must be accessed all at once.
		
		When retrieved, your buffer must be big enough to store the entire
		value.  The File Manager will not truncate or pad any value.  (If
		you supply more space than is required, the extra bytes will be
		unchanged).
		
		For fork properties, you use the FSStream or mapped file calls,
		which allow you to access part of the value.
	kFSSizeAttribute
		The size (in bytes) of a property's value.  This may require up
		to 8 bytes to store (in the case of a fork property; for non-fork
		properties, it requires at most 4 bytes to store).  Since the File
		Manager knows this is numeric, you may supply 1, 2, 4, or 8 bytes
		when getting or setting a size.  The File Manager will coerce the
		value to or from the given size.  If you supply fewer than 8 bytes,
		and the actual size cannot be represented in the given number of
		bytes, then you will get the E_PropertyBufferFieldTooSmall error.
	kFSTypeAttribute
		This is a basic description of the type of data (i.e. its format)
		stored in a property.  This may be helpful when trying to interpret
		properties that you don't know about.  Note: this is not an attempt
		to give detailed information about the data type stored in a property.
		This attribute is always 4 bytes long.
	kFSNullAttribute
		Used to indicate a non-existent attribute (for the null property).
		This is the attribute field of the null property.  See also
		kFSFileManagerNullProperty.  This attribute is always 0 bytes long.
	kFSForkPhysicalSizeAttribute
		This is the amount of physical storage allocated for a fork property's
		value on the volume's media.  Note that this can be more or less than
		the size attribute (kFSSizeAttribute), depending on how the volume
		has allocated space for the property, and even the property's value.
		
		This attribute is a legacy for certain older APIs.  Its use is
		discouraged.  This attribute may be obsoleted in the future.
		
		This attribute is up to 8 bytes in length.  It follows the same
		rules as kFSSizeAttribute for coercion to smaller lengths. 
	kFSStateAttribute
		This attribute contains dynamic state information about a property.
		It consists of a series of flags; these flags are common to all
		properties.
		
		This attribute is not currently supported.  It is intended to be
		used for things such as a read-only flag on a property-by-property
		basis.  Since it is dynamic, it would tend to reflect any temporary
		software locks.
	kFSPolicyAttribute
		This attribute contains policy (static) information about a property.
		It consists of a series of flags; these flags are common to all
		properties.
		
		This attribute is not currently supported.
}
	kFSValueAttribute			= 'valu';
	kFSSizeAttribute			= 'size';
	kFSTypeAttribute			= 'type';
	kFSNullAttribute			= 'null';
	kFSForkPhysicalSizeAttribute = 'fsiz';
	kFSStateAttribute			= 'stat';
	kFSPolicyAttribute			= 'plcy';

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished FSProperty Tag Templates
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
	FSForkType
		A list of the defined types of the File Manager's fork property.
		These values would appear in the forkType field of the property tag
		for a fork.  Remember, there is only one fork property; use the forkType
		to select which kind of fork you want.
	
	kFSDataFork
		Specifies the data fork.  This is the same as the data fork from the
		Files API, or the normal file contents of single-forked file systems
		such as MS-DOS or Unix.
	kFSResourceFork
		Specifies the resource fork.  This is the same as the resource fork from
		the Files API.
}
	kFSInvalidForkType			= 0;
	kFSDataFork					= 1;
	kFSResourceFork				= 2;


TYPE
	FSForkType							= UInt16;
{
	FSForkPropertyTag
		The property tag used for the File Manager's fork property.  You can
		declare a variable of this type, fill out the individual fields, then
		use the M_AssignStructToFileManagerForkPropertyTag macro to copy the
		tag into a more opaque (and generic) property tag stored in a normal
		FSProperty.
	
	version
		Version of the property and tag.  This should be set to the value
		kFSCurrentReleasedVersion.
	forkType
		Specifies which kind of fork.  See FSForkType.
	instance
		Specifies which instance of the given kind of fork.  
}
	FSForkPropertyTagPtr = ^FSForkPropertyTag;
	FSForkPropertyTag = RECORD
		version:				UInt16;
		forkType:				FSForkType;
		instance:				UInt32;
	END;

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Volume Set Distinguished Selector
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{  }

CONST
	kFSVolumeSet				= 'vlm#';						{  }

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished Properties by Creator
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
============================================================================
	Distinguished FileManager Universe (kFSUniverseCreator) Properties  
============================================================================
}
{
----------------------------------------------------------------------------
	Distinguished FileManager Universe (kFSUniverseCreator) Selectors
----------------------------------------------------------------------------
}
{  }
	kFSCreatorList				= 'crt#';						{  }
	kFSVolumeSetList			= 'vls#';						{  }
	kFSBootVolume				= 'btvl';						{  }

{
----------------------------------------------------------------------------
	Distinguished FileManager Universe  (kFSUniverseCreator) Constants
----------------------------------------------------------------------------
}
{
============================================================================
	Distinguished FileManager BootVolumeSet (kFSBootVolumeSetCreator) Properties  
============================================================================
}
{
----------------------------------------------------------------------------
	Distinguished FileManager BootVolumeSet (kFSBootVolumeSetCreator) Constants
----------------------------------------------------------------------------
}
{
============================================================================
	Distinguished FileManager (kFSFileManagerCreator) Properties  
============================================================================
}
{
----------------------------------------------------------------------------
	Distinguished FileManager (kFSFileManagerCreator) Selectors
----------------------------------------------------------------------------
}
{  }
	kFSNullPropertySelector		= 'null';						{  }
	kFSForkProperty				= 'fork';						{  }
	kFSForkPropertyList			= 'frk#';						{  }
	kFSSimplePropertyList		= 'smp#';						{  }
	kFSPropertyList				= 'fsp#';						{  }
	kFSPropertyDescriptorList	= 'pdr#';						{  }
	kFSObjectContainerObjectRef	= 'ocor';						{  }
	kFSObjectContainerObjectType = 'ocot';						{  }
	kFSObjectContainerPersistentReference = 'ocpr';				{  }
	kFSObjectRef				= 'oref';						{  }
	kFSObjectPersistentReference = 'pref';						{  }
	kFSObjectType				= 'otyp';						{  }
	kFSObjectName				= 'onam';						{  }
	kFSObjectCreationDate		= 'cdat';						{  }
	kFSObjectModificationDate	= 'mdat';						{  }
	kFSObjectBackupDate			= 'bdat';						{  }
	kFSObjectAccessDate			= 'adat';						{  }
	kFSObjectLock				= 'olck';						{  }
	kFSObjectCumulativeModificationDate = 'cmdt';				{  }
	kFSObjectCumulativeBackupDate = 'cbdt';						{  }
	kFSObjectCumulativeAccessDate = 'cadt';						{  }
	kFSVolumeCreationDate		= 'vcdt';						{  }
	kFSVolumeModificationDate	= 'vmdt';						{  }
	kFSVolumeBackupDate			= 'vbdt';						{  }
	kFSVolumeFileCount			= 'vflc';						{  }
	kFSVolumeFolderCount		= 'vfdc';						{  }
	kFSVolumeObjectCount		= 'vobc';						{  }
	kFSVolumeFormat				= 'vfmt';						{  }
	kFSVolumeCapability			= 'vcap';						{  }
	kFSVolumeBlockCount			= 'vbct';						{  }
	kFSVolumeBlockFreeCount		= 'vbfr';						{  }
	kFSVolumeBlockSize			= 'vbsz';						{  }
	kFSVolumeSize				= 'vsiz';						{  }
	kFSVolumeFreeSize			= 'vbfs';						{  }
	kFSVolumeIOQuanta			= 'vioq';						{  }
	kFSVolumeLock				= 'vlck';						{  }
	kFSFileCount				= 'filc';						{  }
	kFSFolderCount				= 'fldc';						{  }
	kFSObjectCount				= 'objc';						{  }
	kFSVolumeStartupFolderObjectRef = 'strt';					{  }

{
----------------------------------------------------------------------------
	Distinguished FileManager (kFSFileManagerCreator) Constants
----------------------------------------------------------------------------
}
{  }
{  }
{  }
{  }
{  }
{  }
{  }
{
============================================================================
	Distinguished UserExperience (kFSUserExperienceCreator) Properties  
============================================================================
}
{
----------------------------------------------------------------------------
	Distinguished UserExperience (kFSUserExperienceCreator) Selectors
----------------------------------------------------------------------------
}
{
	The first five selectors are properties of a container and take an ObjectSpecification
	to an object on a volume. The remaining properties are properties of a volume and take
	an ObjectSpecification to the volume in question.
}
	kFSFinderBasicInfo			= 'bfin';						{  The old style FInfo record. }
	kFSFinderExtendedInfo		= 'xfin';						{  The old style FXInfo record. }
	kFSFinderVolumeInfo			= 'fvin';						{  Eight longwords of private Finder volume information }
	kFSDocumentType				= 'type';						{  Just the finder fdType information. }
	kFSDocumentCreator			= 'crtr';						{  Just the finder fdCreator information. }
	kFSComment					= 'cmnt';						{  The comment from the DTDB for an object. }
																{   }
	kFSApplication				= 'APPL';						{  Returns a FSObjectRef to the most recent  }
																{  application specified in tag. }
	kFSApplicationList			= 'APP#';						{  Returns a list of 'APPL's }
	kFSLargeIcon				= 'ICN#';						{  The tag for this property is a type/creator pair }
	kFSLarge4BitIcon			= 'icl4';						{  The tag for this property is a type/creator pair }
	kFSLarge8BitIcon			= 'icl8';						{  The tag for this property is a type/creator pair }
	kFSSmallIcon				= 'ics#';						{  The tag for this property is a type/creator pair }
	kFSSmall4BitIcon			= 'ics4';						{  The tag for this property is a type/creator pair }
	kFSSmall8BitIcon			= 'ics8';						{  The tag for this property is a type/creator pair }

{
----------------------------------------------------------------------------
	Distinguished UserExperience (kFSUserExperienceCreator) Constants
----------------------------------------------------------------------------
}
{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Object Property Simple Value Types
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
	FSSimplePropertyValueType
}
	kFSVTInvalidValueType		= 0;
	kFSVTSInt8					= 1;
	kFSVTUInt8					= 2;
	kFSVTSInt16					= 3;
	kFSVTUInt16					= 4;
	kFSVTSInt32					= 5;
	kFSVTUInt32					= 6;
	kFSVTSInt64					= 7;
	kFSVTUInt64					= 8;
	kFSVTBoolean				= 9;
	kFSVTByteCount				= 10;
	kFSVTByteOffset				= 11;
	kFSVTItemCount				= 12;
	kFSVTOptionBits				= 13;
	kFSVTBufferDescriptor		= 14;
	kFSVTBufferElementDescriptor = 15;
	kFSVTOSType					= 16;
	kFSVTCStr					= 17;
	kFSVTCharacterStr			= 18;
	kFSVTPStr					= 19;
	kFSVTPersistentTextObject	= 20;
	kFSVTUniCodeStr				= 21;
	kFSVTDOSDate				= 22;
	kFSVTISO9660Date			= 23;
	kFSVTMacDate				= 24;
	kFSVTUNIXDate				= 25;
	kFSVTTimeObject				= 26;
	kFSVTCount					= 27;
	kFSVTValueTypeEnumerator	= 28;
	kFSVTDate					= 29;
	kFSVTForkPropertyType		= 30;
	kFSVTName					= 31;
	kFSVTObjectRef				= 32;
	kFSVTOffset					= 33;
	kFSVTPersistentObjectReference = 34;
	kFSVTProperty				= 35;
	kFSVTPropertyDescriptor		= 36;
	kFSVTSize					= 37;
	kFSVTEnumeratedValueTypeMask = $7F;
	kFSVTPropertyCreatorDefinedValueType = $80;


TYPE
	FSSimplePropertyValueType			= UInt32;
{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished FileManager FSProperty Value Templates
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
	FSFileSystemKind is used to indicate a type of filesystem.
	Apple reserves values with all lower case letters, and
	those whose first two bytes are nil (for compatibility
	with old FSID's)
}
	FSFileSystemKind					= OSType;
{  }

CONST
	kFSInvalidObjectType		= $00000000;
	kFStheUniverse				= $00000001;
	kFStheBootVolumeSet			= $00000002;
	kFSVolume					= $00000004;
	kFSFolder					= $00000008;
	kFSFile						= $00000010;


TYPE
	FSObjectType						= OptionBits;
{
	FSBlockCount holds a number of blocks (such as total blocks or free blocks on
	a volume).
	
	FSBlockNum holds a number specifying a fork block or a volume block.
	
	 Eventually, we will get rid of these private types and use the one
	defined by BlockStorage.  Also note that the value is intentionally signed.
	This solves several problems that arise from the lack of proper 64 bit math
	support.  
}
	FSBlockCount						= SInt64;
	FSBlockCountPtr 					= ^FSBlockCount;
	FSBlockNum							= SInt64;
	FSBlockNumPtr 						= ^FSBlockNum;
{  }

CONST
	kFSUnspecifiedVolumeCapabilities = $00000000;
	kFSSupportsNotification		= $00000001;
	kFSSupportsAFPPermissions	= $00000002;
	kFSSupportsACLPermissions	= $00000004;
	kFSSupportsLogicalToPhysical = $00000008;
	kFSSupportsRangeLocking		= $00000010;
	kFSFilesAPILooselyCompliant	= $00000020;
	kFSFilesAPIStrictlyCompliant = $00000040;
	kFSSupportsUserProperties	= $00000080;
	kFSSupportsShortNames		= $00000100;
	kFSSupportsFSObjectMove		= $00000200;
	kFSSupportsFSObjectCopy		= $00000400;
	kFSSupportsAccessDeny		= $00000800;
	kFSSupportsBooting			= $00001000;
	kFSSupportsSystem			= $00002000;
	kFSSupportsDesktop			= $00004000;
	kFSIsEjectable				= $00008000;


TYPE
	FSVolumeCapabilities				= OptionBits;
{  }
	FSVolumeFormat						= OSType;
{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished FileManager Simple Property Tag Templates
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{  }
	FSFileManagerSimplePropertyTagPtr = ^FSFileManagerSimplePropertyTag;
	FSFileManagerSimplePropertyTag = RECORD
		version:				FSFileManagerPropertyTagVersion;
		reserved:				UInt16;
		instance:				UInt32;
	END;

{
============================================================================
	FileManager Date Property Tag Templates:
		kFSObjectCreationDate
		kFSObjectModificationDate
		kFSObjectBackupDate
		kFSObjectAccessDate
		kFSObjectCumulativeModificationDate
		kFSObjectCumulativeBackupDate
		kFSObjectCumulativeAccessDate
============================================================================
}
{  }

CONST
	kFSInvalidDateFormat		= 0;
	kFSDOSDateFormat			= 1;
	kFSISO9660DateFormat		= 2;
	kFSMacDateFormat			= 3;
	kFSUNIXDateFormat			= 4;
	kFSTimeObjectFormat			= 5;


TYPE
	FSObjectDateType					= UInt16;
{  }
	FSObjectDatePropertyTagPtr = ^FSObjectDatePropertyTag;
	FSObjectDatePropertyTag = RECORD
		version:				FSFileManagerPropertyTagVersion;
		dateType:				FSObjectDateType;
		instance:				UInt32;
	END;

{
============================================================================
	FileManager Name (kFSObjectName) Property Tag Templates
============================================================================
}
{  }

CONST
	kFSInvalidStringFormat		= 0;
	kFSCharacterStringFormat	= 1;
	kFSCStringFormat			= 2;
	kFSPStringFormat			= 3;
	kFSUniCodeStringFormat		= 4;
	kFSPersistentTextObjectStringFormat = 5;


TYPE
	FSObjectNameType					= UInt16;
{  }
	FSObjectNamePropertyTagPtr = ^FSObjectNamePropertyTag;
	FSObjectNamePropertyTag = RECORD
		version:				FSFileManagerPropertyTagVersion;
		nameType:				FSObjectNameType;
		instance:				UInt32;
	END;

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished UserExperience FSProperty Value Templates
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
	FSUserExperienceApplicationInfo		= FSObjectRef;
	FSUserExperienceApplicationInfoPtr	= ^FSUserExperienceApplicationInfo;
	FSObjectCommentType					= FSObjectNameType;
{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Distinguished UserExperience FSProperty Tags
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
	FSIconPropertyTagPtr = ^FSIconPropertyTag;
	FSIconPropertyTag = RECORD
		creator:				OSType;
		documentType:			OSType;
	END;

	FSApplicationInfoPropertyTagPtr = ^FSApplicationInfoPropertyTag;
	FSApplicationInfoPropertyTag = RECORD
		creator:				OSType;
		object:					FSObjectRef;
	END;

	FSObjectCommentPropertyTagPtr = ^FSObjectCommentPropertyTag;
	FSObjectCommentPropertyTag = RECORD
		reserved:				UInt16;
		commentype:				FSObjectCommentType;
		instance:				UInt32;
	END;

{ >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> C a p a b i l i t i e s <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< }
{
****************************************************************************
	PROPERTY ACCESS METHODS
****************************************************************************
}
{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Object Property Simple Values
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
============================================================================
	Simple Property Access Method (Get/Set/Create/Delete )
============================================================================
}
{
	FSPropertyDescriptor's associate simple FSProperty's with specific instances
	of their attributes  An attribute location is either an offset within some addressed
	buffer or the address of the attribute. This is determined from the context those
	calls that use FSPropertyDescriptors -- if an associated buffer is provided with
	a property descriptor in a call, the location is an offset.  If the associated
	buffer is elided, the location is an address.
	
}
	FSPropertyDescriptorPtr = ^FSPropertyDescriptor;
	FSPropertyDescriptor = RECORD
		property:				FSProperty;
		offsetOrAddress:		UInt32;
		length:					ByteCount;
	END;

{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Object Property Fork Values
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{   }
	FSForkAccessConstraintsPtr = ^FSForkAccessConstraints;
	FSForkAccessConstraints = RECORD
		allowThisTask:			FSObjectPrivileges;
		denyThisKernelProcess:	FSObjectPrivilegesDenied;
		denyOtherKernelProcesses: FSObjectPrivilegesDenied;
	END;

{  }

CONST
	kFSAllocAny					= $00000000;					{  need not be contiguous; partial allocation is OK }
	kFSAllocContiguous			= $00000001;					{  if set, allocated space must be contiguous }
	kFSAllocAllOrNothing		= $00000002;					{  if set, must allocate all of the space asked for (no partial success) }


TYPE
	FSForkAllocationPolicy				= OptionBits;
{  }

CONST
	kFSAtMark					= 0;
	kFSFromStart				= 1;
	kFSFromLEOF					= 2;
	kFSFromMark					= 3;


TYPE
	FSForkPosition						= UInt32;
{   }
	FSForkPositionDescriptorPtr = ^FSForkPositionDescriptor;
	FSForkPositionDescriptor = RECORD
		positionOffset:			FSOffset;
		positionMode:			FSForkPosition;
	END;

{
============================================================================
	Stream-based Access Method
============================================================================
}
{  }

CONST
	kFSDefaultIOOptions			= 0;
	kFSWriteThroughCache		= $80000000;
	kFSDoNotCache				= $40000000;
	kFSSequentialAccess			= $20000000;
	kFSStreamIOOptionsReservedMask = $1FFFFFFF;					{   ~(kFSDefaultIOOptions | kFSWriteThroughCache | kFSDoNotCache | kFSSequentialAccess) }


TYPE
	FSStreamIOOptions					= OptionBits;
	FSStreamIOOptionsPtr				= ^FSStreamIOOptions;
{   }
	FSStreamObjID						= ObjectID;
{  }

CONST
	kFSRangeLockNullOptions		= $00000000;
	kFSRangeLockExclusive		= $00000001;					{  Allow exclusive read/write to range (else shared read-only) }
	kFSRangeLockAllowPartial	= $00000002;					{  Lock until next conflicting lock (else don't lock anything) }
	kFSRangeLockMaximalLength	= $00000004;					{  Lock extends to largest possible (positive) offset }


TYPE
	FSRangeLockOptions					= OptionBits;
{  }

CONST
	kFSMarkPinToEOF				= $00000001;					{  if set, and the new mark would exceed the EOF, then set the mark to the EOF }


TYPE
	FSStreamSetMarkOptions				= OptionBits;
{
============================================================================
	Memory-Mapped Access Method
============================================================================
}
{   }
	FSBackingStoreObjID					= BackingObjectID;
{
****************************************************************************
	NAVIGATION & ENUMERATION
****************************************************************************
}
{  }

CONST
	kFSInvalidObjectIteratorCreationOptions = 0;
	kFSIncludetheUniverse		= $00000001;
	kFSIncludetheBootVolumeSet	= $00000002;
	kFSIncludeVolumes			= $00000004;
	kFSIncludeFolders			= $00000008;
	kFSIncludeFiles				= $00000010;
	kFSTraverseEmbeddedContainers = $01000000;


TYPE
	FSObjectIteratorCreationOptions		= OptionBits;
{  }

CONST
	kFSInvalidObjectIteratorMovement = 0;
	kFSObjectEnter				= 1;
	kFSObjectExit				= 2;


TYPE
	FSObjectIteratorMovement			= UInt32;
{
============================================================================
	Object Iteration
============================================================================
}
{  }
	FSObjectIteratorObjID				= ObjectID;
{
  These are the public (returned by FSObjectIteratorGetInformation) iterator states.
  Other private state flags are defined in FileManagerPriv.i.
}

CONST
	kFSInvalidIteratorState		= $0000;						{  End of Iteration state }
	kFSIteratorEOI				= $0001;						{  End of Iteration state }
	kFSIteratorSOI				= $0002;						{  Start of Iteration state }


TYPE
	FSObjectIteratorState				= UInt32;
{
============================================================================
	Object Resolution
============================================================================
}
{  }

CONST
	kFSObjectPathwayInvalidTag	= $00000000;
	kFSObjectPathwayIteratorMovementElement = $00000001;
	kFSObjectPathwayPropertyElement = $00000002;


TYPE
	FSObjectPathwayTag					= UInt32;
{  }
	FSObjectPathwayElementPtr = ^FSObjectPathwayElement;
	FSObjectPathwayElement = RECORD
		tag:					FSObjectPathwayTag;
		CASE INTEGER OF
		0: (
			movement:			FSObjectIteratorMovement;
			);
		1: (
			property:			FSPropertyDescriptor;
			);
	END;

{ >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> F a c i l i t i e s <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< }
{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	Status Codes
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	SNS SERVICES: FILE SYSTEMS EVENTS
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
}
{
============================================================================
	SNSKind									SNSSubject					Info
	--------------------------------------	--------------------------	-----------------------
	kFSEventObjectChangedKind				FSEventObjectSubject		NULL
	kFSEventVolumeStateChangedKind			FSEventVolumeSubject		NULL
	kFSEventVolumeObjectsChangedKind		FSEventVolumeSubject		FSEventPersistentInfo/FSEventDeleteInfo
	kFSEventPropertyChangedForObjectsKind	FSEventPropertySubject		FSEventPersistentInfo
	kFSEventObjectPropertiesChangedKind		FSEventObjectSubject		FSEventPropertyInfo
	kFSEventObjectsinFolderChangedKind		FSEventObjectSubject		FSEventPersistentInfo/FSEventDeleteInfo
	
Note: FSEventPersistentInfo/FSEventDeleteInfo means that for create we use FSEventPersistentInfo
because no body has access to the the run time ID of a new object.  For delete we use 
FSEventDeleteInfo because nothing can be done with PersistentInfo of a deleted objects,
but those with run time ID may wish to match them.
============================================================================
}
{
	The FSEventOperation type is used in the interface whenever an event needs
	to report the manner in which something changed: was it created, deleted,
	or just modified. The FSEventOperations are enumerated values for which
	the following constants are currently defined:
}

CONST
	kFSInvalidEvent				= 0;
	kFSEventAny					= 1;
	kFSEventCreation			= 2;
	kFSEventMounting			= 2;
	kFSEventComingOnline		= 2;
	kFSEventDeletion			= 3;
	kFSEventUnmounting			= 3;
	kFSEventGoingOffline		= 3;
	kFSEventModification		= 4;


TYPE
	FSEventOperation					= UInt32;
{
	FSEventSNSKind:  SNSKind for File System events
}

CONST
	kFSEventObjectChangedKind	= 'fsoc';						{   0x66736f63   }
	kFSEventVolumeStateChangedKind = 'fsvc';					{   0x66737663   }
	kFSEventPropertyChangedForObjectsKind = 'fspo';				{   0x6673706f   }
	kFSEventObjectPropertiesChangedKind = 'fsop';				{   0x66736f70   }
	kFSEventObjectsinFolderChangedKind = 'fsfo';
	kFSEventVolumeObjectsChangedKind = 'fsvo';

{
	FSEventSNSService:  SNSService for File System events
}
	kFSEventNotificationService	= 'fsys';

{  }

TYPE
	FSEventObjectInfoPtr = ^FSEventObjectInfo;
	FSEventObjectInfo = RECORD
		count:					ItemCount;
		objects:				ARRAY [0..0] OF FSObjectRef;
	END;

{  }
	FSEventPersistentInfoPtr = ^FSEventPersistentInfo;
	FSEventPersistentInfo = RECORD
		count:					ItemCount;
		objects:				ARRAY [0..0] OF FSObjectPersistentReference;
	END;

	FSEventDeleteInfoPtr = ^FSEventDeleteInfo;
	FSEventDeleteInfo = RECORD
		object:					FSObjectRef;
		date:					FSDate;
		name:					ARRAY [0..0] OF TextObjectUnit;
	END;

{  }
	FSEventObjectPropertyInfoPtr = ^FSEventObjectPropertyInfo;
	FSEventObjectPropertyInfo = RECORD
		count:					ItemCount;
		properties:				ARRAY [0..0] OF FSProperty;
	END;

{  }
	FSEventObjectSubjectPtr = ^FSEventObjectSubject;
	FSEventObjectSubject = RECORD
		operation:				FSEventOperation;
		object:					FSObjectRef;
	END;

	FSEventVolumeSubjectPtr = ^FSEventVolumeSubject;
	FSEventVolumeSubject = RECORD
		operation:				FSEventOperation;
		volume:					FSVolumeObjID;
	END;

{  }
	FSEventObjectPropertySubjectPtr = ^FSEventObjectPropertySubject;
	FSEventObjectPropertySubject = RECORD
		operation:				FSEventOperation;
		property:				FSProperty;
	END;

{ >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> U N I O N S <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< }
{ >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> C O M P A B I L I T Y <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< }
{  }
{  }
{  }
{  }
{$ENDC}
{$ALIGN RESET}
{$POP}

{$SETC UsingIncludes := FileManagerTypesIncludes}

{$ENDC} {__FILEMANAGERTYPES__}

{$IFC NOT UsingIncludes}
 END.
{$ENDC}
