{
 	File:		IOMemoryLists.p
 
 	Contains:	Memory List API
 
 	Version:	Technology:	Copland
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
}
{$IFC UNDEFINED UsingIncludes}
{$SETC UsingIncludes := 0}
{$ENDC}

{$IFC NOT UsingIncludes}
 UNIT IOMemoryLists;
 INTERFACE
{$ENDC}

{$IFC UNDEFINED __IOMEMORYLISTS__}
{$SETC __IOMEMORYLISTS__ := 1}

{$I+}
{$SETC IOMemoryListsIncludes := UsingIncludes}
{$SETC UsingIncludes := 1}

{$IFC UNDEFINED __TYPES__}
{$I Types.p}
{$ENDC}
{$IFC UNDEFINED __KERNEL__}
{$I Kernel.p}
{$ENDC}

{$PUSH}
{$ALIGN POWER}
{$LibExport+}


TYPE
	MemListRef = ^LONGINT;
	MemListDescriptorRef = ^LONGINT;

CONST
	kMemListByteAbsolute		= $00000001;
	kMemListByteRelative		= $00000002;
	kMemListPageAbsolute		= $00000004;
	kMemListPageRelative		= $00000008;
	kMemListPhysicalExtentAbsolute = $00000010;
	kMemListPhysicalExtentRelative = $00000020;
	kMemListStaticLogicalExtentAbsolute = $00000040;
	kMemListStaticLogicalExtentRelative = $00000080;
	kMemListInputExtentAbsolute	= $00000100;
	kMemListInputExtentRelative	= $00000200;


TYPE
	MemListWhence						= UInt32;
{
****************************************************************************

	Basic error types
	
 ***************************************************************************
}

CONST
	E_MemListSuccess			= $00000000;
	E_MemListCantAllocate		= -2600;
	E_MemListEndOfList			= -2601;
	E_MemListNotPrivileged		= -2602;
	E_MemListBadMemList			= -2603;
	E_MemListOutOfRange			= -2604;


TYPE
	MemListInfoPtr = ^MemListInfo;
	MemListInfo = RECORD
		numDescriptors:			ItemCount;
		numRanges:				ItemCount;
		numPages:				ItemCount;
		isFinalized:			BOOLEAN;
		isPrepared:				BOOLEAN;
	END;

	MemListDescriptorInfoPtr = ^MemListDescriptorInfo;
	MemListDescriptorInfo = RECORD
		len:					ByteCount;
		preparationOptions:		IOPreparationOptions;
		parentDescriptor:		MemListDescriptorRef;
		parentMemList:			MemListRef;
		isPrepared:				BOOLEAN;
	END;

{
******************************************************************************
 *******************************************************************************

	Memory List Creation and Initialization
	
 *******************************************************************************
 *****************************************************************************
}
FUNCTION MemListCreate(anticipatedRanges: ItemCount; VAR newMemList: MemListRef): OSStatus; C;
FUNCTION MemListCreatePriv(anticipatedRanges: ItemCount; addressSpace: AddressSpaceID; VAR newMemList: MemListRef): OSStatus; C;
FUNCTION MemListCreatePhysPriv(anticipatedRanges: ItemCount; VAR newMemList: MemListRef): OSStatus; C;
FUNCTION MemListAddRange(memList: MemListRef; start: LogicalAddress; length: ByteCount): OSStatus; C;
FUNCTION MemListAddPhysRange(memList: MemListRef; start: PhysicalAddress; length: ByteCount): OSStatus; C;
FUNCTION MemListFinalize(finalizeList: MemListRef; VAR newDescriptor: MemListDescriptorRef): OSStatus; C;
{
******************************************************************************
 *******************************************************************************

	Memory List Descriptor Manipulation
	
 *******************************************************************************
 *****************************************************************************
}
FUNCTION MemListAddSimpleDescriptor(srcDescriptor: MemListDescriptorRef; len: ByteCount; VAR newDescriptor: MemListDescriptorRef): OSStatus; C;
FUNCTION MemListCloneDescriptor(srcDescriptor: MemListDescriptorRef; VAR newDescriptor: MemListDescriptorRef): OSStatus; C;
FUNCTION MemListDeleteDescriptor(deleteDescriptor: MemListDescriptorRef): OSStatus; C;
FUNCTION MemListPrepareDescriptorForIO(srcDescriptor: MemListDescriptorRef; requestedLen: ByteCount; granularity: ByteCount; options: OptionBits; VAR newDescriptor: MemListDescriptorRef; VAR mappedLen: ByteCount): OSStatus; C;
FUNCTION MemListCheckPointDescriptor(checkpointDescriptor: MemListDescriptorRef; theOptions: IOCheckpointOptions): OSStatus; C;
FUNCTION MemListGetInfo(infoDescriptor: MemListRef; VAR info: MemListInfo): OSStatus; C;
FUNCTION MemListGetDescriptorInfo(infoDescriptor: MemListDescriptorRef; VAR info: MemListDescriptorInfo): OSStatus; C;
FUNCTION MemListDescriptorSeek(seekDescriptor: MemListDescriptorRef; whence: MemListWhence; offset: SInt32; VAR newOffset: SInt32): OSStatus; C;
FUNCTION MemListGetExtent(descriptor: MemListDescriptorRef; requestedSize: ByteCount; VAR staticLogicalAddress: LogicalAddress; VAR physicalAddress: PhysicalAddress; VAR extentLen: ByteCount): OSStatus; C;
FUNCTION MemListGetPage(descriptor: MemListDescriptorRef; VAR staticLogicalAddress: LogicalAddress; VAR physicalAddress: PhysicalAddress; VAR bytesUsedInPage: ByteCount): OSStatus; C;
{
******************************************************************************
 *******************************************************************************

	Memory List Descriptor Usage
	
 *******************************************************************************
 *****************************************************************************
}
FUNCTION MemListDescriptorDataCopy(srcDescriptor: MemListDescriptorRef; destDescriptor: MemListDescriptorRef; bytesToCopy: ByteCount): OSStatus; C;
FUNCTION MemListDescriptorDataCopyToMemory(srcDescriptor: MemListDescriptorRef; destBuffer: LogicalAddress; bytesToCopy: ByteCount): OSStatus; C;
FUNCTION MemListDescriptorDataCopyFromMemory(srcBuffer: LogicalAddress; destDescriptor: MemListDescriptorRef; bytesToCopy: ByteCount): OSStatus; C;
FUNCTION MemListDescriptorDataCompare(descriptor1: MemListDescriptorRef; descriptor2: MemListDescriptorRef; bytesToCompare: ByteCount; VAR different: BOOLEAN; VAR firstDifferentByte: ByteCount): OSStatus; C;
FUNCTION MemListDescriptorDataCompareWithMemory(descriptor: MemListDescriptorRef; buffer: LogicalAddress; bytesToCompare: ByteCount; VAR different: BOOLEAN; VAR firstDifferentByte: ByteCount): OSStatus; C;
{
******************************************************************************
 *******************************************************************************

	Memory List Extended Functionality
	
 *******************************************************************************
 *****************************************************************************
}
FUNCTION MemListDelete(deleteList: MemListRef): OSStatus; C;
FUNCTION MemListExportIOPreparationTable(srcDescriptor: MemListDescriptorRef; VAR outputTable: IOPreparationTablePtr): OSStatus; C;
FUNCTION MemListDeleteIOPreparationTable(srcDescriptor: MemListDescriptorRef; VAR deleteTable: IOPreparationTable): OSStatus; C;
{$ALIGN RESET}
{$POP}

{$SETC UsingIncludes := IOMemoryListsIncludes}

{$ENDC} {__IOMEMORYLISTS__}

{$IFC NOT UsingIncludes}
 END.
{$ENDC}
